@@ -1,33 +1,28 @@
 # -*- coding: utf-8 -*-
 
 import mimetypes
-import os
-import tempfile
 import unicodedata
-from StringIO import StringIO
 
 import pkg_resources
 from AccessControl import Unauthorized
-from Products.CMFPlone.utils import base_hasattr
-from Products.CMFPlone.utils import safe_unicode
-from Products.Five import BrowserView
-from appy.pod.renderer import CsvOptions
-from appy.pod.renderer import Renderer
+from appy.pod.renderer import CsvOptions, Renderer
 from appy.pod.styles_manager import TableProperties
-from collective.documentgenerator import config
-from collective.documentgenerator import utils
-from collective.documentgenerator.content.pod_template import IPODTemplate
-from collective.documentgenerator.interfaces import CyclicMergeTemplatesException
-from collective.documentgenerator.interfaces import IDocumentFactory
-from collective.documentgenerator.interfaces import PODTemplateNotFoundError
-from collective.documentgenerator.utils import remove_tmp_file
 from plone import api
 from plone.app.uuid.utils import uuidToObject
 from plone.i18n.normalizer.interfaces import IFileNameNormalizer
+from Products.CMFPlone.utils import base_hasattr, safe_unicode
+from Products.Five import BrowserView
+from StringIO import StringIO
 from zope.annotation.interfaces import IAnnotations
-from zope.component import getMultiAdapter
-from zope.component import queryAdapter
-from zope.component import queryUtility
+from zope.component import getMultiAdapter, queryAdapter, queryUtility
+
+from collective.documentgenerator import config, utils
+from collective.documentgenerator.content.pod_template import IPODTemplate
+from collective.documentgenerator.interfaces import (
+    CyclicMergeTemplatesException, IDocumentFactory, PODTemplateNotFoundError)
+from collective.documentgenerator.utils import (remove_tmp_file,
+                                                temporary_file_name)
+
 from .. import _
 
 HAS_FINGERPOINTING = None
@@ -73,6 +68,7 @@ class DocumentGenerationView(BrowserView):
             from collective.fingerpointing.config import AUDIT_MESSAGE
             from collective.fingerpointing.logger import log_info
             from collective.fingerpointing.utils import get_request_information
+
             # add logging message to fingerpointing log
             user, ip = get_request_information()
             action = 'generate_document'
@@ -193,8 +189,7 @@ class DocumentGenerationView(BrowserView):
         that will be merged into the current generated document.
         """
         document_template = pod_template.get_file()
-        tmp_dir = os.getenv('CUSTOM_TMP', None)
-        temp_filename = tempfile.mktemp(suffix='.{extension}'.format(extension=output_format), dir=tmp_dir)
+        temp_filename = temporary_file_name('.{extension}'.format(extension=output_format))
 
         # Prepare rendering context
         helper_view = self.get_generation_context_helper()
@@ -260,7 +255,6 @@ class DocumentGenerationView(BrowserView):
         if output_format == "csv":
             csvOptions = CsvOptions(fieldSeparator=pod_template.csv_field_delimiter,
                                     textDelimiter=pod_template.csv_string_delimiter)
-
         renderer = Renderer(
             StringIO(document_template.data),
             generation_context,
@@ -271,6 +265,7 @@ class DocumentGenerationView(BrowserView):
             raiseOnError=raiseOnError,
             imageResolver=api.portal.get(),
             forceOoCall=True,
+            html=True,
             optimalColumnWidths=optimalColumnWidths,
             distributeColumns=distributeColumns,
             stylesMapping=stylesMapping,
@@ -301,6 +296,7 @@ class DocumentGenerationView(BrowserView):
         generation_context = self.get_base_generation_context(helper_view, pod_template)
         utils.update_dict_with_validation(generation_context,
                                           {'context': getattr(helper_view, 'context', None),
+                                           'portal': api.portal.get(),
                                            'view': helper_view},
                                           _("Error when merging helper_view in generation context"))
         utils.update_dict_with_validation(generation_context, self._get_context_variables(pod_template),
