@@ -2,20 +2,20 @@
 
 import logging
 import os
-import tempfile
 
 import appy.pod
-from Products.CMFPlone.utils import safe_unicode
 from appy.shared.utils import executeCommand
-from collective.documentgenerator import _
-from collective.documentgenerator import config
-from collective.documentgenerator.content.pod_template import IPODTemplate
-from collective.documentgenerator.utils import remove_tmp_file
 from plone import api
 from plone.namedfile.file import NamedBlobFile
+from Products.CMFPlone.utils import safe_unicode
 from zExceptions import Redirect
 from zope.i18n import translate
 
+from collective.documentgenerator import _, config
+from collective.documentgenerator.content.pod_template import IPODTemplate
+from collective.documentgenerator.utils import create_temporary_file
+from collective.documentgenerator.utils import remove_tmp_file
+
 logger = logging.getLogger('collective.documentgenerator: styles update')
 
 CONVSCRIPT = '{}/converter.py'.format(os.path.dirname(appy.pod.__file__))
@@ -75,9 +75,8 @@ def _update_template_styles(pod_template, style_template_filename):
         pod_template.style_modification_md5 and pod_template.current_md5 == pod_template.style_modification_md5
     # save in temporary file, the template
     temp_file = create_temporary_file(pod_template.odt_file, 'pod_template.odt')
-    new_template = open(temp_file.name, 'w')
-    new_template.write(pod_template.odt_file.data)
-    new_template.close()
+    with open(temp_file.name, 'w') as new_template:
+        new_template.write(pod_template.odt_file.data)
 
     # merge style from templateStyle in template
     cmd = '{path} {script} {tmp_file} {extension} -e ' \
@@ -109,23 +108,14 @@ def _update_template_styles(pod_template, style_template_filename):
     # read the merged file
     resTempFileName = '.res.'.join(temp_file.name.rsplit('.', 1))
     if os.path.isfile(resTempFileName):
-        resTemplate = open(resTempFileName, 'rb')
-        # update template
-        result = NamedBlobFile(data=resTemplate.read(),
-                               contentType='application/vnd.oasis.opendocument.text',
-                               filename=pod_template.odt_file.filename)
-        pod_template.odt_file = result
+        with open(resTempFileName, 'rb') as resTemplate:
+            # update template
+            result = NamedBlobFile(data=resTemplate.read(),
+                                   contentType='application/vnd.oasis.opendocument.text',
+                                   filename=pod_template.odt_file.filename)
+            pod_template.odt_file = result
+            # if only styles were modified: update the style_modification_md5 attribute
+            if style_changes_only:
+                pod_template.style_modification_md5 = pod_template.current_md5
         remove_tmp_file(resTempFileName)
-        # if only styles were modified: update the style_modification_md5 attribute
-        if style_changes_only:
-            pod_template.style_modification_md5 = pod_template.current_md5
-
     remove_tmp_file(temp_file.name)
-
-
-def create_temporary_file(initial_file=None, base_name=''):
-    tmp_file = tempfile.NamedTemporaryFile(suffix=base_name, delete=False)
-    if initial_file:
-        tmp_file.file.write(initial_file.data)
-    tmp_file.close()
-    return tmp_file
