@@ -75,7 +75,7 @@ class TestConfigView(PODTemplateFunctionalTest):
         form = self.browser.getForm('form')
         pythonpath_input = form.getControl(name='form.widgets.uno_path')
         pythonpath_input.value = 'yolo'
-        form.submit('Sauver')
+        form.submit(name='form.buttons.save')
         msg = "python path validator should have raised an 'invalid python path' warning"
         self.assertTrue(
             'Le chemin python spécifié semble erroné' in self.browser.contents,
@@ -87,7 +87,7 @@ class TestConfigView(PODTemplateFunctionalTest):
         form = self.browser.getForm('form')
         pythonpath_input = form.getControl(name='form.widgets.uno_path')
         pythonpath_input.value = os.path.abspath('../../bin/python')
-        form.submit('Sauver')
+        form.submit(name='form.buttons.save')
         msg = "python path validator should have raised an 'python do not have uno library' warning"
         self.assertTrue(
             "L'importation de la librairie UNO dans votre environnement python a échoué" in self.browser.contents,
@@ -100,7 +100,7 @@ class TestConfigView(PODTemplateFunctionalTest):
         form = self.browser.getForm('form')
         pythonpath_input = form.getControl(name='form.widgets.uno_path')
         pythonpath_input.value = os.path.abspath('../../bin/python')
-        form.submit('Sauver')
+        form.submit(name='form.buttons.save')
         msg = 'no warnings should have been raised'
         self.assertTrue('Changements enregistrés' in self.browser.contents, msg)
 
